@@ -10,7 +10,7 @@
 
 #include <limits.h>
 #include <float.h>
-/* #undef GLIB_HAVE_ALLOCA_H */
+#define GLIB_HAVE_ALLOCA_H
 
 /* Specifies that GLib's g_print*() functions wrap the
  * system printf functions.  This is useful to know, for example,
@@ -58,15 +58,15 @@ typedef unsigned int guint32;
 
 #define G_HAVE_GINT64 1          /* deprecated, always true */
 
-G_GNUC_EXTENSION typedef signed long long gint64;
-G_GNUC_EXTENSION typedef unsigned long long guint64;
+typedef signed long gint64;
+typedef unsigned long guint64;
 
-#define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
-#define G_GUINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##ULL))
+#define G_GINT64_CONSTANT(val)	(val##L)
+#define G_GUINT64_CONSTANT(val)	(val##UL)
 
-#define G_GINT64_MODIFIER "ll"
-#define G_GINT64_FORMAT "lli"
-#define G_GUINT64_FORMAT "llu"
+#define G_GINT64_MODIFIER "l"
+#define G_GINT64_FORMAT "li"
+#define G_GUINT64_FORMAT "lu"
 
 
 #define GLIB_SIZEOF_VOID_P 8
@@ -110,11 +110,12 @@ typedef unsigned long guintptr;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 70
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MICRO_VERSION 5
 
 #define G_OS_UNIX
 
 #define G_VA_COPY va_copy
+#define G_VA_COPY_AS_ARRAY 1
 
 
 #ifndef __cplusplus
@@ -198,7 +199,7 @@ typedef int GPid;
 
 #define GLIB_SYSDEF_AF_UNIX 1
 #define GLIB_SYSDEF_AF_INET 2
-#define GLIB_SYSDEF_AF_INET6 24
+#define GLIB_SYSDEF_AF_INET6 10
 
 #define GLIB_SYSDEF_MSG_OOB 1
 #define GLIB_SYSDEF_MSG_PEEK 2
